from subprocess import run

def command_cmd(command_,options):
        #TODO: deberia verificar que si el sistema es windows.
        if (options):
            return run(f'{command_}',options,shell=True) 
        return run(f'{command_}',shell=True)


from pathlib import PurePath
from command_cmd import command_cmd


def mkdir(destination = False,obtions = False,debug=False):
    if (debug):
        print(destination,obtions)
    if (destination):
        destination = PurePath(destination)
        return command_cmd(f'mkdir {destination}',obtions)
    return False